@@ -6,11 +6,17 @@ from fakts.grants.meta.failsafe import FailsafeGrant
 from fakts.grants.remote.public_redirect_grant import PublicRedirectGrant
 from herre.fakts.herre import FaktsHerre
 from koil.composition.qt import QtPedanticKoil
+from fakts.discovery.qt.selectable_beacon import (
+    QtSelectableDiscovery,
+    SelectBeaconWidget,
+)
 
 class ArkitektPluginWidget(MikroNapariWidget):
 
     def __init__(self, viewer: 'napari.viewer.Viewer'):
 
+        x = SelectBeaconWidget()
+
         app = ConnectedApp(
             koil=QtPedanticKoil(parent=self),
             rekuest=ArkitektRekuest(),
@@ -18,7 +24,9 @@ class ArkitektPluginWidget(MikroNapariWidget):
                 subapp="napari",
                 grant=FailsafeGrant(
                     grants=[
-                        PublicRedirectGrant(name="Napari", scopes=["openid"]),
+                        PublicRedirectGrant(name="Napari", scopes=["openid"],discovery=QtSelectableDiscovery(
+                            widget=x
+                        )),
                     ]
                 ),
                 assert_groups={"mikro", "arkitekt"},
@@ -29,7 +37,6 @@ class ArkitektPluginWidget(MikroNapariWidget):
 
         super(ArkitektPluginWidget, self).__init__(viewer, app)
 
-
         app.enter()
 
 
